==> openGion6.9.4.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           VARCHAR2 (  10 )                    NOT NULL            /*  20 帳票ID   */
 , KBTEXT           VARCHAR2 (   1 )                    NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              VARCHAR2 (  30 )                    NOT NULL            /*  40 項目     */
 , SEQ              NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        NUMBER   (   5 )        DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       VARCHAR2 (   9 )        DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            VARCHAR2 (   1 )                    NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                        /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (  20 )                                        /* 100 設変番号 */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET            VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET           VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET           VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD            VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD            VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD           VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01;

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           VARCHAR2 (  10 )                    NOT NULL            /*  20 帳票ID   */
 , KBTEXT           VARCHAR2 (   1 )                    NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              VARCHAR2 (  30 )                    NOT NULL            /*  40 項目     */
 , SEQ              NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        NUMBER   (   5 )        DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       VARCHAR2 (   9 )        DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            VARCHAR2 (   1 )                    NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                        /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (  20 )                                        /* 100 設変番号 */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET            VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET           VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET           VARCHAR2 (  10 )                                        /* 850 作成者   */
 , DYUPD            VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD            VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD           VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
